/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* vim: set ts=2 sw=2 et tw=78: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsParserConstants_h_
#define nsParserConstants_h_
const char16_t  kNewLine          = '\n';
const char16_t  kCR               = '\r';
const char16_t  kLF               = '\n';
const char16_t  kTab              = '\t';
const char16_t  kSpace            = ' ';
const char16_t  kQuote            = '"';
const char16_t  kApostrophe       = '\'';
const char16_t  kLessThan         = '<';
const char16_t  kGreaterThan      = '>';
const char16_t  kAmpersand        = '&';
const char16_t  kForwardSlash     = '/';
const char16_t  kBackSlash        = '\\';
const char16_t  kEqual            = '=';
const char16_t  kMinus            = '-';
const char16_t  kPlus             = '+';
const char16_t  kExclamation      = '!';
const char16_t  kSemicolon        = ';';
const char16_t  kHashsign         = '#';
const char16_t  kAsterisk         = '*';
const char16_t  kUnderbar         = '_';
const char16_t  kComma            = ',';
const char16_t  kLeftParen        = '(';
const char16_t  kRightParen       = ')';
const char16_t  kLeftBrace        = '{';
const char16_t  kRightBrace       = '}';
const char16_t  kQuestionMark     = '?';
const char16_t  kLeftSquareBracket  = '[';
const char16_t  kRightSquareBracket = ']';
const char16_t kNullCh           = '\0';

#endif // nsParserConstants_h_
